@Echo Off
Rem *****************************************************************************
Rem  Patch #2 for Service Profiler v1.2
Rem *****************************************************************************
Rem  Wrightia, S.A. (c) 2011
Rem
Rem  Purpose:
Rem     Replace AIX PPC and PPC-64 native libraries.
Rem     Due to base changes in some base classes, all native libraries have also
Rem     to be replaced.
Rem
Rem  Input parameters:
Rem     %1          : IS_DIR  (The Integration Server installation directory)
Rem
Rem  Results:
Rem     1. Copies new versions of the AIX native libraries into the Service
Rem			Profiler installed run directory structure.
Rem
Rem  Exit codes:
Rem     0  - OK
Rem
Rem *****************************************************************************

SetLocal
PushD

If Exist ..\error (
   If Exist ..\error\*.upd.bat (
      Call :logWarning "Previous updates with error were found: %0 skipped."
      Exit /b 100
   )
) Else (
   MkDir ..\error
)

date /T >> updates.log
time /T >> updates.log

Set xISHome=%~1
Set xTargetHome=%xISHome%\serviceprofiler

If NOT Exist %xTargetHome% (
   Call :logWarning "Directory '%xTargetHome%' was not found: '%0' not applied."
   goto end-of-patch
   )

   Rem update (or create) native libraries
:Copy_1
   Call :log "Copying UNIX libraries"
   Copy ..\..\serviceprofiler\lib\lib*.* "%xTargetHome%\lib\"     >> updates.log
   If ERRORLEVEL 0 (
      Goto Copy_2
   ) Else (
      Exit /b %ERRORLEVEL%
   )

:Copy_2
   Call :log "Copying WINDOWS libraries"
   Copy ..\..\serviceprofiler\lib\*.dll "%xTargetHome%\lib\"   >> updates.log
   If ERRORLEVEL 0 (
      Goto Copy_3
   ) Else (
      Exit /b %ERRORLEVEL%
   )

   Rem update (or create) Java libraries
:Copy_3
   Call :log "Copying Java libraries"
   Copy ..\..\serviceprofiler\lib\*.jar "%xTargetHome%\lib\"      >> updates.log
   If ERRORLEVEL 0 (
      Goto Copy_4
   ) Else (
      Exit /b %ERRORLEVEL%
   )

:Copy_4
   Call :log "Replace package-static Java libraries"
   move .\issprof.v1-2.p2.jar ..\..\..\code\jars\static\wia-profiler-core-11.jar
   If NOT ERRORLEVEL 0 (
      Exit /b %ERRORLEVEL%
   )

:end-of-patch

PopD
EndLocal

Exit /b 0


:log
   echo %~1 >> updates.log
   Goto :EOF

: logError
   Call :log "ERROR %~1"
   Goto :EOF

:logWarning
   Call :log "WARNING %~1"
   Goto :EOF

:logInfo
   Call :log "INFO %~1"
   Goto :EOF

