#!/bin/ksh
# *****************************************************************************
#  Patch #2 for Service Profiler v1.2
# *****************************************************************************
#  Wrightia, S.A. (c) 2011
#
#  Purpose:
#     Replace AIX PPC and PPC-64 native libraries.
#     Due to base changes in some base classes, all native libraries have also
#     to be replaced.
#
#  Input parameters:
#     $1          : IS_DIR  (The Integration Server installation directory)
#
#  Results:
#     1. Copies new versions of the AIX native libraries into the Service
#			Profiler installed run directory structure.
#
#  Exit codes:
#     0  - OK
#
# *****************************************************************************

log() {
   echo "[$1] [`date +%C%y-%m-%d\ %H:%M:%S`] $2" >> updates.log
}

logError() {
   log "ERROR" "$1"
}

logWarning() {
   log "WARNING" "$1"
}

logInfo() {
   log "INFO" "$1"
}

#--< MAIN	>------------------------------------------------------------------
if [ -d ../error ]; then
   if [ ! -z "`ls ../error/ | sort | grep .upd.sh`" ] ; then
      logWarning "Previous updates with error were found: '$0 $*' skipped."
      exit 100
   fi
else
   mkdir ../error
fi

xISHome=$1
xTargetHome=$xISHome/serviceprofiler
if [ -d "$xTargetHome" ] ; then
   # update (or create) HP-UX native libraries
   cp ../../serviceprofiler/lib/* "$xTargetHome/lib/"
   xEL=$?
   if [ $xEL -eq 0 ]; then
      logInfo "All dynamic libraries copied successfully."
      mv -f ./issprof.v1-2.p2.jar ../../../code/jars/static/wia-profiler-core-11.jar
      xEL=$?
      if [ $xEL -eq 0 ]; then
         logInfo "wia-profiler-core-11.jar moved successfully."
         logInfo "Update '$0' successful."
      else
         logError "Error '$xEL' copying libraries."
         exit $xEL
      fi
   else
      logError "Error '$xEL' copying libraries."
      exit $xEL
   fi
else
   logWarning "Directory '$xISHome/serviceprofiler' was not found: '$0 $*' not applied."
fi

